@@ -714,7 +714,10 @@ fn string_width(text: &str) -> usize {
 }
 
 fn real_string_width(text: &str) -> usize {
-    text.lines().map(unicode_width::UnicodeWidthStr::width).max().unwrap_or(0)
+    text.lines()
+        .map(unicode_width::UnicodeWidthStr::width)
+        .max()
+        .unwrap_or(0)
 }
 
 fn __columns_width(
@@ -734,8 +737,6 @@ fn __columns_width(
         });
     });
 
-    println!("{:?}", widths);
-
     // check if we don't need to check all spans as it a heavy load function.
     // it suppose to save us time and resources
     if cells
@@ -749,8 +750,6 @@ fn __columns_width(
         __adjust_width(&mut widths, cells, count_rows, count_columns, 1);
     }
 
-    println!("{:?}", widths);
-
     // remove not visible cells to print everything correctly
     (0..count_rows).for_each(|row| {
         let mut n_removed = 0;
